<?php
/**
 * Relation Controller for Book Component
 * 
 * @package    Joomla.Tutorials
 * @subpackage Components
 * @link http://docs.joomla.org/Developing_a_Model-View-Controller_Component_-_Part_4
 * @license		GNU/GPL
 */

// No direct access
defined( '_JEXEC' ) or die( 'Restricted access' );
echo "Relation controller <br />";

/**
 * Book Controller
 *
 * @package    Joomla.Tutorials
 * @subpackage Components
 */
class RecipesControllerRelation extends JController
{
	/**
	 * constructor (registers additional tasks to methods)
	 * @return void
	 */
	function __construct()
	{
		parent::__construct();

		// Register Extra tasks
		$this->registerTask( 'add'  , 	'edit' );
		$this->registerTask( 'unpublish', 	'publish');
	}

	/**
	 * display the edit form
	 * @return void
	 */
	function edit()
	{
		JRequest::setVar( 'view', 'relation' );
		JRequest::setVar( 'layout', 'form'  );
		JRequest::setVar('hidemainmenu', 1);

		parent::display();
	}

	/**
	 * save a record (and redirect to main page)
	 * @return void
	 */
	function save()
	{
		$model = $this->getModel('relation');

		if ($model->store($post)) {
			$msg = JText::_( 'Relation Saved!' );
		} else {
			$msg = JText::_( 'Error Saving Relation' );
		}

		// Check the table in so it can be edited.... we are done with it anyway
		$link = 'index.php?option=com_recipe&controller=relation';
		$this->setRedirect($link, $msg);
	}

	/**
	 * remove record(s)
	 * @return void
	 */
	function remove()
	{
		$model = $this->getModel('relation');
		if(!$model->delete()) {
			$msg = JText::_( 'Error: One or More Relations Could not be Deleted' );
		} else {
			$msg = JText::_( 'Relation(s) Deleted' );
		}

		$this->setRedirect( 'index.php?option=com_recipe&controller=relation', $msg );
	}
	
	/**
	* Publishes or Unpublishes one or more records
	* @param array An array of unique category id numbers
	* @param integer 0 if unpublishing, 1 if publishing
	* @param string The current url option
	*/
	function publish()
	{
		// Initialize variables
		$db			=& JFactory::getDBO();
		$user		=& JFactory::getUser();
		$cid		= JRequest::getVar( 'cid', array(), 'post', 'array' );
		$task		= JRequest::getCmd( 'task' );
		$publish	= ($task == 'publish');
		$n			= count( $cid );

		if (empty( $cid )) {
			return JError::raiseWarning( 500, JText::_( 'Aucun element selectionne' ) );
		}

		JArrayHelper::toInteger( $cid );
		$cids = implode( ',', $cid );

		$query = 'UPDATE #__relation'
		. ' SET published = ' . (int) $publish
		. ' WHERE id IN ( '. $cids .' )'
		;
		$db->setQuery( $query );
		if (!$db->query()) {
			return JError::raiseWarning( 500, $row->getError() );
		}
		$msg = JText::_( 'Items published or unpublished', $n );
		$this->setRedirect( 'index.php?option=com_recipe&controller=relation', $msg );

	}
	
	/**
	 * cancel editing a record
	 * @return void
	 */
	function cancel()
	{
		$msg = JText::_( 'Operation Cancelled' );
		$this->setRedirect( 'index.php?option=com_recipe&controller=relation', $msg );
	}
}
